<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>RemoveLayer</name>
    <message>
        <source>&amp;Remove Layer</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Usuń warstwę</translatorcomment>
        <translation type="obsolete">&amp;Usuń warstwę</translation>
    </message>
    <message>
        <location filename="../RemoveLayerInit.js" line="+2"/>
        <source>&amp;Delete Layer</source>
        <translation>&amp;Usuń warstwę</translation>
    </message>
</context>
</TS>
